<?php

/*

FrontendSimpleEdit update processor

*/

$clearCache = $modx->getOption('clearCache', $scriptProperties, 1);
$resource_id = $modx->getOption('id', $scriptProperties, 0);

$modx->lexicon->load('resource');

ini_set('display_errors',1);

if($resource_id && is_numeric($resource_id)){
    
    if (!$modx->hasPermission('save_document')) {
        return $modx->error->failure($modx->lexicon('access_denied'));
    }
    
    $resource = $modx->getObject('modResource', $resource_id);
    
    if (empty($resource)) return $modx->error->failure($modx->lexicon('resource_err_nfs',array('id' => $scriptProperties['id'])));
    
    if($resource && $resource->checkPolicy('save')){
        
        $resource_data = array_merge($resource->toArray(), $scriptProperties);
        $tv_collection = $resource->getMany('TemplateVars');
        
        foreach($tv_collection as $tv){
            if(!isset($scriptProperties['tv'.$tv->id])) $resource_data['tv'.$tv->id] = $tv->value;
        }
        
        $resource_data['tvs'] = true;
        $resource_data['clearCache'] = $clearCache;
        
        $response = $modx->runProcessor(
            'resource/update',
            $resource_data,
            array(
                'processors_path' => $modx->getOption( 'processors_path' ),
                'action' => 'update'
            )
        );
        
        if ($response->isError()) {
            
            return $modx->error->failure($response->getMessage());
            
        }else{
            
            $result = $response->getResponse();
            
            //var_dump($result); exit;
            
            return $result;
            
        }
        
    }
    
}

return $modx->error->failure($modx->lexicon('resource_err_nfs'), array('id' => $resource_id));
